#!/usr/bin/env python3
import sys
import os
import argparse

from PyConSolv.ConfGen import PyConSolv
from PyConSolv.misc.analysis import Analysis


def main():
    ver = '0.9.3.0'
    parser = argparse.ArgumentParser(prog = 'PyConSolv', description='Process commandline arguments for PyconSolv')
    parser.add_argument('input', help = 'input file in XYZ format')
    parser.add_argument('-c', '--charge',  nargs='?', default=0, type=int, help = 'charge of the system, default 0')
    parser.add_argument('-m', '--method', nargs='?', default='PBE0', type=str, help='ORCA optimization/frequency calculations method of choice, default PBE0')
    parser.add_argument('-b', '--basis', nargs='?', default='def2-SVP', type=str, help='basis set to be used for calculations, default def2-SVP')
    parser.add_argument('-d', '--dispersion', nargs='?', default='D4', type=str, help='dispersion corrections, default = D4')
    parser.add_argument('-s', '--solvent', nargs='?', default='Water', type=str, help='solvent to be used for MD simulations/ OM Calculations, default Water')
    parser.add_argument('-p', '--cpu', nargs='?', default=12, type=int, help='number of cpu cores to be used for calculations, default 12')
    parser.add_argument('-mult', '--multiplicity',  nargs='?', default=1, type=int, help = 'multiplicity of the system, default 1')
    parser.add_argument('-a', '--analyze', action='store_true', help='analyze a simulation')
    parser.add_argument('-nosp', '--nosp', action='store_true', help='do not run single point calculations')
    parser.add_argument('-mask', '--mask', nargs='?', default=0, type=str, help='atomid mask for clustering')
    parser.add_argument('-cluster', '--cluster', nargs='?', default=0, type=str, help='clustering method')
    parser.add_argument('-e', '--engine', nargs='?', default='amber', type=str, help='MD engine to be used for equilibration and simulation')
    parser.add_argument('-v', '--version', action = 'version', version = '%(prog)s {}'.format(ver))

    args = parser.parse_args()

    inputfilepath = os.path.abspath(args.input)

    if args.analyze:
        if not args.mask:
            print('Warning, you have not provided an input mask for alignment, please provide a list of atom ids in the format: 1,2,3-10\n')
            mask = input()
        else:
            mask = args.mask
        if not args.cluster:
            print('Please provide a clustering method: [kmeans, dbcscan, dpeaks, hierarchical]\n')
            cluster = input()
        else:
            cluster = args.cluster
        analysis = Analysis(path = inputfilepath, alignMask= mask)
        analysis.run(clustering=cluster, nosp = args.nosp)

    elif '.xyz' not in inputfilepath:
        print('Path does not contain a valid XYZ file\n')
        sys.exit()

    else:
        conf = PyConSolv(inputfilepath)
        conf.run(charge= args.charge , method = args.method, basis = args.basis , dsp = args.dispersion , cpu = args.cpu ,
                solvent = args.solvent, multiplicity = args.multiplicity, engine = args.engine )
    sys.exit()

if __name__ == '__main__':
    main()